@@ -38,9 +38,12 @@ class MarsRequest;
 
 class MarsRequest {
 public:  // methods
+
     MarsRequest();
+
     explicit MarsRequest(const std::string&);
     explicit MarsRequest(eckit::Stream&, bool lowercase = false);
+
     MarsRequest(const std::string&, const std::map<std::string, std::string>&);
     MarsRequest(const std::string&, const eckit::Value&);
 
@@ -60,12 +63,10 @@ public:  // methods
     size_t countValues(const std::string&) const;
     bool has(const std::string&) const;
 
-
     bool is(const std::string& param, const std::string& value) const;
 
     const std::vector<std::string>& values(const std::string&, bool emptyOk = false) const;
 
-
     template <class T>
     size_t getValues(const std::string& name, std::vector<T>& v, bool emptyOk = false) const;
 
@@ -83,6 +84,12 @@ public:  // methods
 
     void unsetValues(const std::string&);
 
+    /// Splits a MARS request into multiple requests along the provided key
+    std::vector<MarsRequest> split(const std::string& keys) const;
+
+    /// Splits a MARS request into multiple requests along the indicated keys
+    std::vector<MarsRequest> split(const std::vector<std::string>& keys) const;
+
     /// Merges one MarsRequest into another
     /// @todo Improve performance -- uses O(N^2) search / merge in std::list's
     void merge(const MarsRequest& other);
@@ -108,7 +115,10 @@ public:  // methods
 
     void erase(const std::string& param);
 
+    std::string asString() const;
+
 public:  // static methods
+
     static MarsRequest parse(const std::string& s, bool strict = false);
     static std::vector<MarsRequest> parse(std::istream&, bool strict = false);
 
