@@ -101,8 +101,7 @@ void StepRange::print(std::ostream& s) const
         eckit::Time f{static_cast<long>(from_*3600.), true};
         eckit::Time t{static_cast<long>(to_*3600.), true};
 
-        TimeUnit unit = std::min(maxUnit(f), maxUnit(t));
-        s << canonical(f, unit) << '-' << canonical(t, unit);
+        s << canonical(f) << '-' << canonical(t);
     }
 }
 
